Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2354)

Unified Diff: build/android/pylib/base/base_test_runner.py

Issue 16820002: [Android] Separate concepts of pushing test data and installing test apk. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Addressed Nilesh's comments Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | build/android/pylib/gtest/test_runner.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/android/pylib/base/base_test_runner.py
diff --git a/build/android/pylib/base/base_test_runner.py b/build/android/pylib/base/base_test_runner.py
index 0af5f502b1396314aedb5aac5261b10d3def043d..f2dd817044aec4762c46c589c90c0bca576a215f 100644
--- a/build/android/pylib/base/base_test_runner.py
+++ b/build/android/pylib/base/base_test_runner.py
@@ -81,18 +81,23 @@ class BaseTestRunner(object):
"""
raise NotImplementedError
- def PushDependencies(self):
- """Push all dependencies to device once before all tests are run."""
+ def InstallTestPackage(self):
+ """Installs the test package once before all tests are run."""
+ pass
+
+ def PushDataDeps(self):
+ """Push all data deps to device once before all tests are run."""
pass
def SetUp(self):
"""Run once before all tests are run."""
Forwarder.KillDevice(self.adb, self.tool)
+ self.InstallTestPackage()
if self._push_deps:
- logging.info('Pushing deps to device.')
- self.PushDependencies()
+ logging.info('Pushing data deps to device.')
+ self.PushDataDeps()
else:
- logging.warning('Skipping pushing deps to device.')
+ logging.warning('Skipping pushing data deps to device.')
def TearDown(self):
"""Run once after all tests are run."""
« no previous file with comments | « no previous file | build/android/pylib/gtest/test_runner.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698